@@ -34,6 +34,7 @@ class SurveyElement(dict):
         u"intent": unicode,
         u"jr:count" : unicode,
         u"bind": dict,
+        u"instance": dict,
         u"control": dict,
         u"media": dict,
         # this node will also have a parent and children, like a tree!
@@ -41,6 +42,7 @@ class SurveyElement(dict):
         u"children": list,
         u"itemset": unicode,
         u"choice_filter": unicode,
+        u"query": unicode,
         u"autoplay": unicode,
         u"flat": lambda: False,
     }
